pub enum UploadBatchFileError {
FileUploadError(FilesError),
}Expand description
Errors that can occur when uploading a batch file.
Variants
FileUploadError(FilesError)
An error occurred when uploading the file to the API.